@@ -14,5 +14,5 @@
 #' @method plot3d templatebrain
 #' @importFrom rgl plot3d
 plot3d.templatebrain <- function(x, col='grey', alpha=0.3, ...) {
-  plot3d(get(paste0(deparse(substitute(x)), ".surf")), col=col, alpha=alpha, ...)
+  plot3d(get(paste0(as.character(x), ".surf")), col=col, alpha=alpha, ...)
 }
